@@ -10,29 +10,29 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.18-92.1.6.el5.src.rpm ]
+if [ ! -r kernel-2.6.18-92.1.17.el5.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/centos/5.2/updates/SRPMS/kernel-2.6.18-92.1.6.el5.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/centos/5.2/updates/SRPMS/kernel-2.6.18-92.1.17.el5.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.18-92.1.6.el5.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.18-92.1.17.el5.src.rpm || die "Can't install source package."
 
 cd /usr/src/redhat/SOURCES/ || die "Can't chdir to /usr/src/redhat/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.3-20080715.tar.gz ]
+if [ ! -r ccs-patch-1.6.5-20081111.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.3-20080715.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.5-20081111.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/redhat/SPECS/kernel-2.6.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6.spec	2008-06-26 02:00:24.000000000 +0900
-+++ kernel-2.6.spec	2008-06-27 09:13:36.000000000 +0900
+--- kernel-2.6.spec	2008-11-04 22:27:30.000000000 +0900
++++ kernel-2.6.spec	2008-11-06 09:24:06.000000000 +0900
 @@ -66,7 +66,7 @@
  # that the kernel isn't the stock distribution kernel, for example,
  # by setting the define to ".local" or ".bz123456"
  #
 -#% define buildid
-+%define buildid _tomoyo_1.6.3
++%define buildid _tomoyo_1.6.5
  #
  %define sublevel 18
  %define kversion 2.6.%{sublevel}
@@ -55,19 +55,18 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -4692,6 +4695,11 @@
+@@ -4816,6 +4819,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.3-20080715.tar.gz
-+sed -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -92.1.6.el5/" -- Makefile
-+patch -sp1 < patches/ccs-patch-2.6.18-92.1.6.el5.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.5-20081111.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.18-centos-5.2.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -4751,6 +4759,9 @@
+@@ -4875,6 +4882,9 @@
  for i in *.config
  do
    mv $i .config
@@ -78,11 +77,11 @@ patch << "EOF" || die "Can't patch spec file."
    make ARCH=$Arch nonint_oldconfig > /dev/null
    echo "# $Arch" > configs/$i
 EOF
-mv kernel-2.6.spec kernel-2.6.18-92.1.6.el5_tomoyo_1.6.3.spec || die "Can't rename spec file."
+mv kernel-2.6.spec ccs-kernel.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
-echo "Edit /tmp/kernel-2.6.18-92.1.6.el5_tomoyo_1.6.3.spec if needed, and run"
-echo "rpmbuild -bb --without kabichk /tmp/kernel-2.6.18-92.1.6.el5_tomoyo_1.6.3.spec"
+echo "Edit /tmp/ccs-kernel.spec if needed, and run"
+echo "rpmbuild -bb --without kabichk /tmp/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 exit 0
