@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 7's 2.6.23 kernel.
+# This is a kernel build script for Fedora 8's 2.6.26 kernel.
 #
 
 die () {
@@ -10,33 +10,33 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.23.17-88.fc7.src.rpm ]
+if [ ! -r kernel-2.6.26.6-49.fc8.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/7/SRPMS/kernel-2.6.23.17-88.fc7.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/8/SRPMS.newkey/kernel-2.6.26.6-49.fc8.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.23.17-88.fc7.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.26.6-49.fc8.src.rpm || die "Can't install source package."
 
 cd /usr/src/redhat/SOURCES/ || die "Can't chdir to /usr/src/redhat/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.4-20080903.tar.gz ]
+if [ ! -r ccs-patch-1.6.5-20081111.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.4-20080903.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.5-20081111.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /usr/src/redhat/SPECS/kernel-2.6.spec . || die "Can't copy spec file."
+cp -p /usr/src/redhat/SPECS/kernel.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6.spec	2008-05-15 12:30:44.000000000 +0900
-+++ kernel-2.6.spec	2008-05-18 09:27:33.000000000 +0900
+--- kernel.spec	2008-10-18 04:11:15.000000000 +0900
++++ kernel.spec	2008-10-21 15:44:09.000000000 +0900
 @@ -12,7 +12,7 @@
  # that the kernel isn't the stock distribution kernel, for example,
  # by setting the define to ".local" or ".bz123456"
  #
 -#% define buildid .local
-+%define buildid _tomoyo_1.6.4
++%define buildid _tomoyo_1.6.5
  
  # fedora_build defines which build revision of this kernel version we're
  # building. Rather than incrementing forever, as with the prior versioning
-@@ -364,6 +364,11 @@
+@@ -389,6 +389,11 @@
  # to versions below the minimum
  #
  
@@ -48,28 +48,36 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -389,7 +394,7 @@
- #
- %define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.9-7.1
+@@ -442,7 +447,7 @@
+ AutoProv: yes\
+ %{nil}
  
 -Name: kernel%{?variant}
 +Name: ccs-kernel%{?variant}
  Group: System Environment/Kernel
  License: GPLv2
- Version: %{rpmversion}
-@@ -1430,6 +1435,11 @@
+ URL: http://www.kernel.org/
+@@ -791,7 +796,7 @@
+ Provides: kernel-devel = %{rpmversion}-%{release}%{?1}\
+ AutoReqProv: no\
+ Requires(pre): /usr/bin/find\
+-%description -n kernel%{?variant}%{?1:-%{1}}-devel\
++%description -n ccs-kernel%{?variant}%{?1:-%{1}}-devel\
+ This package provides kernel headers and makefiles sufficient to build modules\
+ against the %{?2:%{2} }kernel package.\
+ %{nil}
+@@ -1306,6 +1311,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.4-20080903.tar.gz
-+# sed -i -e 's:EXTRAVERSION =.*:EXTRAVERSION = .17-88.fc7:' -- Makefile
-+patch -sp1 < patches/ccs-patch-2.6.23-fedora-7.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.5-20081111.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.26-fedora-8.diff
 +
- # Any further pre-build tree manipulations happen here.
+ %endif
  
- chmod +x scripts/checkpatch.pl
-@@ -1450,6 +1460,9 @@
+ # Any further pre-build tree manipulations happen here.
+@@ -1331,6 +1340,9 @@
  for i in *.config
  do
    mv $i .config
@@ -80,7 +88,7 @@ patch << "EOF" || die "Can't patch spec file."
    make ARCH=$Arch %{oldconfig_target} > /dev/null
    echo "# $Arch" > configs/$i
 EOF
-mv kernel-2.6.spec ccs-kernel.spec || die "Can't rename spec file."
+mv kernel.spec ccs-kernel.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
