@@ -1,11 +1,11 @@
 /*
  * include/linux/ccs_proc.h
  *
- * /proc interface for SAKURA and TOMOYO.
+ * /proc/ccs/ interface for SAKURA and TOMOYO.
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.5.5   2008/09/03
+ * Version: 1.6.5   2008/11/11
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -19,8 +19,7 @@
 #define __user
 #endif
 
-/*************************  Indexes for /proc interfaces.  *************************/
-
+/* Indexes for /proc/ccs/ interfaces. */
 #define CCS_DOMAINPOLICY          0
 #define CCS_EXCEPTIONPOLICY       1
 #define CCS_SYSTEMPOLICY          2
@@ -35,5 +34,6 @@
 #define CCS_QUERY                11
 #define CCS_MANAGER              12
 #define CCS_UPDATESCOUNTER       13
+#define CCS_EXECUTE_HANDLER      14
 
 #endif
