@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.6.2   2008/06/25
+ * Version: 1.6.5   2008/11/11
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -223,6 +223,7 @@ static int __init ccs_proc_init(void)
 	create_entry("manager",          0600, ccs_dir, CCS_MANAGER);
 	create_entry(".updates_counter", 0400, ccs_dir, CCS_UPDATESCOUNTER);
 	create_entry("version",          0400, ccs_dir, CCS_VERSION);
+	create_entry(".execute_handler", 0666, ccs_dir, CCS_EXECUTE_HANDLER);
 	if (sizeof(struct ccs_page_buffer) < CCS_MAX_PATHNAME_LEN + 1)
 		panic("Bad size!");
 	return 0;
@@ -235,6 +236,3 @@ core_initcall(ccs_proc_init);
 #endif
 
 #endif
-
-/* For older patches. */
-void __init CCSProc_Init(void) {}
